@@ -311,13 +311,12 @@ class VideoClip(Clip):
                             "temp_audiofile with the right extension in write_videofile.")
 
                 audiofile = (name + Clip._TEMP_FILES_PREFIX +
-                             "write_videofile_SOUND.%s" % audio_ext)
+                             "wvf_snd.%s" % audio_ext)
 
         # enough cpu for multiprocessing ? USELESS RIGHT NOW, WILL COME AGAIN
         # enough_cpu = (multiprocessing.cpu_count() > 1)
 
-        verbose_print(verbose, "\nMoviePy: building video file %s\n" % filename
-                      + 40 * "-" + "\n")
+        verbose_print(verbose, "[MoviePy] >>>> Building video %s\n" % filename)
 
         if make_audio:
             self.audio.write_audiofile(audiofile, audio_fps,
@@ -337,7 +336,7 @@ class VideoClip(Clip):
         if remove_temp and make_audio:
             os.remove(audiofile)
 
-        verbose_print(verbose, "\nYour video is ready !\n")
+        verbose_print(verbose, "[MoviePy] >>>> Video ready: %s \n\n"%filename)
 
 
     @requires_duration
@@ -383,7 +382,7 @@ class VideoClip(Clip):
 
         """
 
-        verbose_print(verbose, "MoviePy: Writing frames %s." % (nameformat))
+        verbose_print(verbose, "[MoviePy] Writing frames %s." % (nameformat))
 
         tt = np.arange(0, self.duration, 1.0 / fps)
 
@@ -395,7 +394,7 @@ class VideoClip(Clip):
             self.save_frame(name, t, withmask=withmask)
 
         verbose_print(verbose,
-                      "MoviePy: Done writing frames %s." % (nameformat))
+                      "[MoviePy]: Done writing frames %s.\n\n" % (nameformat))
 
         return filenames
 
@@ -776,6 +775,60 @@ class VideoClip(Clip):
         self.audio = self.audio.fx(fun, *a, **k)
 
 
+
+
+
+
+class UpdatedVideoClip(VideoClip):
+    """
+        
+    Class of clips whose make_frame requires some objects to
+    be updated. Particularly practical in science where some
+    algorithm needs to make some steps before a new frame can
+    be generated.
+    
+    UpdatedVideoClips have the following make_frame:
+
+    >>> def make_frame(t):
+    >>>     while self.world.clip_t < t:
+    >>>         world.update() # updates, and increases world.clip_t
+    >>>     return world.to_frame()
+
+    Parameters
+    -----------
+
+    world
+      An object with the following attributes:
+      - world.clip_t : the clip's time corresponding to the
+          world's state
+      - world.update() : update the world's state, (including
+        increasing world.clip_t of one time step)
+      - world.to_frame() : renders a frame depending on the world's state
+
+    ismask
+      True if the clip is a WxH mask with values in 0-1
+
+    duration
+      Duration of the clip, in seconds
+          
+    """
+    
+    
+    def __init__(self, world, ismask=False, duration=None):
+        
+        self.world = world
+        def make_frame(t):
+            while self.world.clip_t < t:
+                world.update()
+            return world.to_frame()
+        VideoClip.__init__(self, make_frame= make_frame,
+                               ismask=ismask, duration=duration)
+
+
+
+
+
+
 """---------------------------------------------------------------------
 
     ImageClip (base class for all 'static clips') and its subclasses
@@ -1124,4 +1177,4 @@ class TextClip(ImageClip):
         """
         string = string.lower()
         names_list = TextClip.list(arg)
-        return [name for name in names_list if string in name.lower()]
+        return [name for name in names_list if string in name.lower()]
\ No newline at end of file
